#!/bin/bash
# This script is run after the rpm files installation.

################################################################################################################################
# Invoke redescribe and wait $WAIT_SECONDS seconds
# Parameters:
#  WAIT_SECONDS - time to wait after redescribe in seconds
#  LOG_FILE - path to the log file 
################################################################################################################################   
redescribe_and_wait () {

   local RETURN_CODE=0
   local WAIT_SECONDS=$1
   local LOG_FILE=$2

   pushd $ALIVE_BASE/tools/dbcli
   bash ./dbcli.sh control redescribe
   sleep $WAIT_SECONDS
   popd

   if [ $RETURN_CODE -eq 0 ]; then
      echo "Redescribe succeeded" >> $LOG_FILE
      else
      echo "Failed to invoke redescribe. Return code: $RETURN_CODE" >> $LOG_FILE
   fi
}


################################################################################################################################
# Install a dashboard
# Parameters:
#  DASHBOARD_NAME - dashboard file name (without .xml extention)
#  LOG_FILE - path to the log file 
################################################################################################################################   
install_custom_dashboard () {

   local RETURN_CODE=0
   local DASHBOARD_NAME=$1
   local LOG_FILE=$2

   pushd $ALIVE_BASE/tools/dbcli
   bash ./dbcli.sh dashboard import admin $ALIVE_BASE/user/plugins/inbound/DeepSecurityAdapter3/conf/dashboards/$DASHBOARD_NAME.xml --retry 10; RETURN_CODE=$?; echo "RETURN_CODE = $RETURN_CODE" >> $LOG_FILE
   popd

   if [ $RETURN_CODE -eq 0 ]; then
      echo "$DASHBOARD_NAME dashboard has been imported successfully!" >> $LOG_FILE
      else
      echo "failed to import $DASHBOARD_NAME dashboard. Return code: $RETURN_CODE" >> $LOG_FILE
   fi
}

# The name of the log file
LOG_FILE=$ALIVE_BASE/tools/dbcli/log/dbcli.log
ADAPTER_NAME="Deep Security Adapter"

echo "$ADAPTER_NAME - Post install script started" >> $LOG_FILE

# Check for Analytics VM
. $ALIVE_BASE/user/conf/install/common.sh
VMNAME=`getValueFromOVFCache "vm.vmname"`

# Copy in the Deep Security Manager metric selector file.
# This is needed in order to display all 7 metrics.
# Copied to both the UI and Analytics VMs since the samples are on both.
INBOUND=$ALIVE_BASE/user/plugins/inbound
MET_IN=$INBOUND/DeepSecurityAdapter3/conf/metricSelector/DSM_ALL_Metrics.xml
WEBAPPS=/usr/lib/vmware-vcops/tomcat-enterprise/webapps
MET_DEST_DIR=$WEBAPPS/vcops-custom/WEB-INF/classes/resources/reskndmetrics
[ -d $MET_DEST_DIR ] || {
   echo "Metric selector directory does not exist. Creating." >> $LOG_FILE
   mkdir -p $MET_DEST_DIR
}

if [ -f $MET_IN ]; then
   echo "Copying Deep Security metric selector ..." >> $LOG_FILE
   cp $MET_IN $MET_DEST_DIR
else
   echo "ERROR: $MET_IN does not exist or is not a regular file." >> $LOG_FILE
fi

if [ "x$VMNAME" == "x$VM_2_NAME" ]; then
   # Invoke redescribe action
   redescribe_and_wait 30 $LOG_FILE

   # Install the built-in dashboards
   install_custom_dashboard "DSM_Heatmap" $LOG_FILE
   install_custom_dashboard "DSM_Troubleshooting" $LOG_FILE
   install_custom_dashboard "DSM_Top-10" $LOG_FILE
else   
   echo "No further tasks need to be executed on UI VM" >> $LOG_FILE
fi 

# if this is the first (UI) vm, we need to restart the webapp so that the adapter specific icons will be recognized
if [ "x$VMNAME" == "x$VM_1_NAME" ]; then
   service vcopswebenterprise restart
fi

echo "$ADAPTER_NAME - Post install script ended" >> $LOG_FILE

